@@ -9,6 +9,7 @@ from mdpo import __version__
 from mdpo.cli import parse_list_argument
 from mdpo.po2md import pofile_to_markdown
 
+
 DESCRIPTION = 'Markdown files translator using pofiles as reference.'
 
 
@@ -38,7 +39,7 @@ def build_parser():
 
 def parse_options(args):
     parser = build_parser()
-    if '-h' in sys.argv or '--help' in sys.argv:
+    if '-h' in args or '--help' in args:
         parser.print_help()
         sys.exit(0)
     opts = parser.parse_args(args)
